@@ -1,15 +1,19 @@
 import logging
 from typing import Optional, Union
 
-import anypoint.vendor.mureq as requests
+import requests
+
+# Disable urllib warnings
+requests.packages.urllib3.disable_warnings()
 
 REQUEST_TIMEOUT = 60
 
 
 class HttpClient:
 
-    def __init__(self, log: logging.Logger):
+    def __init__(self, log: logging.Logger, proxies: Optional[dict] = None):
         self._log = log
+        self._proxies = proxies
 
     def request(self, url: str,
                 method: str = "GET",
@@ -25,6 +29,7 @@ class HttpClient:
                                  params=parameters,
                                  headers=headers,
                                  timeout=REQUEST_TIMEOUT,
+                                 proxies=self._proxies,
                                  verify=False)
             self._log.debug(f"Received response {method} {url} {parameters if parameters else ''}: {r}")
             if r.status_code >= 400:
